autowisp.pipeline_exceptions — AutoWISP documentation

# Source code for autowisp.pipeline_exceptions

    """Collection of non-standard exceptions raised by the pipeline."""

    git_id = "$Id: e7e91a392bfbdca2618f3a40c6abe4a2cbff918d $"

    class OutsideImageError(IndexError):
        """Attempt to access image data outside the bounds of the image."""

    class ImageMismatchError(ValueError):
        """Attempt to combine incompatible images in some way."""

    class BadImageError(ValueError):
        """An image does not look like it is expected to."""

    class ConvergenceError(RuntimeError):
        """Some iterative procedure failed to converge."""

    class HDF5LayoutError(RuntimeError):
        """Error caused by invalid specification of HDF5 layout."""